@@ -29,7 +29,7 @@
 extern "C"
 {
 #endif
-#ifdef __LINUX__
+#ifdef __linux__
 
 	extern char *back2slash (char *);
 	extern char *get_nextparam(void);
@@ -108,7 +108,7 @@ extern "C"
 	extern void format_ffblk (struct ffblk *blk, struct dirent *dir);
 	extern void InfoMessage (int, char *, char *);
 	extern void InitText (char *);
-	extern void justifie (unsigned char *);
+	extern void justifie (uchar *);
 	extern void kill_rzsz (int voie);
 	extern void maj_menu_options (void);
 	extern void orb_options(void);
@@ -286,6 +286,7 @@ extern "C"
 	extern char *bbs_via (char *);
 	extern char *ch_slash (char *);
 	extern char *ch_slash (char *);
+	extern char *check_dates (time_t date);
 	extern char *comp_bid (char *);
 	extern char *copy_name (int, char *);
 	extern char *cr_to_lf (char *);
@@ -303,6 +304,8 @@ extern "C"
 	extern char *extend_bbs (char *);
 	extern char *fbb_fgets (char *, int, FILE *);
 	extern char *ffwd_str (int voie, char *s);
+	extern char *first_group (void);
+	extern char *get_group_info(char *nom, char *buffer);
 	extern char *heure_mbl (long);
 	extern char *hold_name (long, char *);
 	extern char *idnt_fwd (void);
@@ -316,8 +319,10 @@ extern "C"
 	extern char *mk_passwd (char *chaine);
 	extern char *mot (char *);
 	extern char *new_bloc (int);
+	extern char *next_group (void);
 	extern char *nom_yapp (void);
 	extern char *os (void);
+	extern char *pop_date(long date);
 	extern char *sel_bloc (int, int);
 	extern char *snbgen (void);
 	extern char *snbpers (void);
@@ -344,6 +349,7 @@ extern "C"
 	extern char *xfwd_name (int voie, char *tempname);
 	extern char *xfwd_str (int voie, char *s);
 	extern char *xmodem_str (int voie, char *s);
+	extern char *xuidl(long numero, char *callsign);
 	extern char *yapp_str (int voie, char *s);
 
 #ifdef __FBBDOS__
@@ -512,14 +518,12 @@ extern "C"
 	extern int fbb_write (int, void *, unsigned);
 	extern int fbb_stat (char *filename, struct stat *buf);
 	extern int fbb_rmdir (char *filename);
-#ifdef __LINUX__
+#ifdef __linux__
 	extern int fbb_mkdir (char *filename, int mode);
 #else
 	extern int fbb_mkdir (char *filename);
 #endif
-#ifdef FBB_IO
-	extern int fbb_open (char *filename, int acces, unsigned mode);
-#else
+#ifndef FBB_IO
 	extern int fbb_open (char *, int,...);
 #endif
 	extern int fct_arret (int);
@@ -683,6 +687,7 @@ extern "C"
 	extern int nouvelles_annonces (void);
 	extern int num_bbs (char *);
 	extern int num_voie (char *);
+	extern int aff_ok(int);
 	extern int opn_drv (int, int);
 	extern int out_help (char *);
 	extern int outfich (char *);
@@ -700,13 +705,16 @@ extern "C"
 	extern int pk_sonde (int, int, char *, int *);
 	extern int pos_voie (int);
 	extern int premier_enrg (char *);
-	extern int print_fwd(int, unsigned char, unsigned char, unsigned char, int);
+	extern int print_fwd(int, uchar, uchar, uchar, int);
 	extern int ptctrx (int, char *);
 	extern int putxy (int, int, int);
 	extern int put_annonce (void);
 	extern int put_message (void);
-	extern int put_ui (unsigned char *, int, int);
+	extern int put_ui (uchar *, int, int);
 	extern int question (int);
+	/* Quit routine added by N1URO for cross-platform command set
+	compatability with URONode, FlexNet, Xnet, and others. */
+	extern int quit (void);
 	extern int quick_look (void);
 	extern int rcv_drv (int *, int *, int *, char *, int *, ui_header *);
 	extern int rcv_titre (void);
@@ -817,6 +825,7 @@ extern "C"
 	extern int write_temp_bin (int, int);
 	extern int write_wp (unsigned, Wp *);
 
+
 	extern lcall call2l (char *);
 
 	extern long basic_lzhuf (int mode, char *in_f, char *ou_f);
@@ -831,6 +840,7 @@ extern "C"
 	extern long fbb_filelength (int);
 	extern long file_size (char *);
 	extern unsigned long free_disk (int);
+	extern long hour_to_time (char *);
 	extern long lit_chiffre (int);
 	extern long lzhuf (desc_huf *);
 	extern long maj_date (int, char *);
@@ -854,6 +864,9 @@ extern "C"
 	extern unsigned search_wp_record (lcall, int, unsigned);
 	extern unsigned xms_free (void);
 
+	extern uchar  *ansi_to_ibm(uchar *buffer, int len);
+	extern uchar  *ibm_to_ansi(uchar *buffer, int len);
+
 	unsigned short xendien (unsigned short);
 	unsigned long xendienl (unsigned long);
 
@@ -1149,6 +1162,7 @@ extern "C"
 	extern void mark_fwd (int voie, char mode);
 	extern void mark_reverse_bid (bullist *, int, int *);
 	extern void marque_obuf (void);
+	extern void MD5String (uchar *dest, uchar *source);
 	extern void mbl_disbul (void);
 	extern void mbl_emul (void);
 	extern void mbl_info (void);
@@ -1212,8 +1226,8 @@ extern "C"
 	extern void prompt (int, int);
 	extern void prompt_dos (void);
 	extern void put_mess_fwd (char);
-	extern void put_nr (unsigned char *, int, int);
-	extern void put_rose (unsigned char *, int, int);
+	extern void put_nr (uchar *, int, int);
+	extern void put_rose (uchar *, int, int);
 	extern void q_mark (void);
 	extern void qraloc (void);
 	extern void rcv_rev_fwd (void);
@@ -1246,10 +1260,11 @@ extern "C"
 	extern void send_binary_mess (void);
 	extern void send_copy (void);
 	extern void send_file (int);
+	extern void send_list(int);
 	extern void send_reply (void);
 	extern void send_tnc (int, int);
 	extern void send_wp_mess (void);
-	extern void sendeot (unsigned char);
+	extern void sendeot (uchar);
 	extern void set_binary (int, int);
 	extern void set_bit_fwd (char *, int);
 	extern void set_busy (void);
@@ -1301,7 +1316,7 @@ extern "C"
 	extern void tst_sysop (char *, long);
 	extern void tst_warning (bullist *);
 	extern void user_time_out (void);
-	extern void valide_themes (unsigned, bullist *);
+	extern void valide_themes (unsigned, int, bullist *);
 	extern void valmess (bullist *);
 	extern void var_cpy (int, char *);
 	extern void w_bid (void);
@@ -1331,7 +1346,7 @@ extern "C"
 
 	extern void *m_alloue (unsigned int);
 
-	extern Wps *wp_find (char *);
+	extern Wps *wp_find (char *, int);
 
 #ifdef __cplusplus
 }								/* extern "C" */
