@@ -71,8 +71,6 @@
 #define BUSY_EVENT  8
 #define TIME_EVENT  16
 
-#define TCP_MAXCAN 50
-
 typedef struct
 {
 	int ncan;
@@ -114,7 +112,6 @@ typedef struct
 }
 tport_t;
 
-/* static tcan_t tcan[TCP_MAXCAN]; */
 static tport_t tport[NBPORT];
 
 /* static int last_can = 1; */
@@ -202,8 +199,13 @@ int snd_tcp (int port, int canal, int cmd, char *buffer, int len, Beacon * ptr)
 		break;
 
 	case DATA:
-		ret = tcp_snd_dt (port, canal, buffer, len);
-		break;
+		if (len == 0) {
+/*			fprintf (stderr, "FBB snd_tcp() DATA len = 0 !\n");*/
+			break;
+		}
+		else
+			ret = tcp_snd_dt (port, canal, buffer, len);
+			break;
 	}
 	return (ret);
 }
@@ -216,6 +218,7 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 	int can;
 	int valid;
 	int res;
+	int i;
 
 	*cmd = INVCMD;
 
@@ -229,6 +232,8 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		return 1;
 	}
 	
+	usleep(50000);		/* wait 50 msec to allow interrupt and avoid CPU overload */
+
 	/* Teste s'il y a une connection */
 	tport[*port].tcan[0].sock = p_port[*port].fd;
 	res = s_status (&tport[*port].tcan[0]);
@@ -242,12 +247,17 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		"\377\374\001\000Telnet Initialisation string                                   ";
 
 		int new;
-		int i;
-		int addr_len;
+		unsigned addr_len;
 		struct sockaddr_in sock_addr;
 		addr_len = sizeof (sock_addr);
 
 		new = accept (p_port[*port].fd, (struct sockaddr *) &sock_addr, &addr_len);
+		if (new == -1)
+		{
+			perror ("rcv_tcp() accept");
+			return (FALSE);
+		}
+
 
 		/* Affecter le nouveau socket a un canal vide */
 		for (i = 1; i <= tport[*port].nbcan; i++)
@@ -291,6 +301,8 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 				{
 					sprintf (buf, "\r\n%s BBS. TELNET Access\r\n\r\n", my_call);
 					write (new, buf, strlen (buf));
+/*					fprintf (stderr, "\n%s BBS. TELNET Access\n\n", my_call);*/
+
 				}
 				else
 				{
@@ -313,6 +325,8 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 				}
 			}
 			sprintf (buf, "Callsign : ");
+/*			fprintf (stderr, "Callsign : ");*/
+
 			write (new, buf, strlen (buf));
 
 			val = p_port[*port].pk_t;
@@ -321,389 +335,414 @@ int rcv_tcp (int *port, int *canal, int *cmd, char *buffer, int *len, ui_header
 		}
 	}
 
-	/* Passe au canal suivant pour le polling */
-	++tport[*port].curcan;
-	if (tport[*port].curcan > tport[*port].nbcan)
-		tport[*port].curcan = 1;
-		
-	can = tport[*port].curcan;
-
-	if ((tport[*port].tcan[can].sock == -1) && (tport[*port].tcan[can].state != DISCONNECT))
+	for (i = 1 ; i <= tport[*port].nbcan ; i++)
 	{
-		sprintf (buffer, "(%d) DISCONNECTED fm TCP", can);
-		tport[*port].tcan[can].state = DISCONNECT;
-		clear_can (*port, can);
-		*len = strlen (buffer);
-		*cmd = COMMAND;
-		*canal = can;
-		return (TRUE);
-	}
+		/* Passe au canal suivant pour le polling */
+		++tport[*port].curcan;
+		if (tport[*port].curcan > tport[*port].nbcan)
+			tport[*port].curcan = 1;
 
-	/* Canal de communication */
-	res = s_status (&tport[*port].tcan[can]);
+		can = tport[*port].curcan;
 
-	if (res & TIME_EVENT)
-	{
-		sprintf (buf, "Timeout, disconnected !\r\n");
-		write (tport[*port].tcan[can].sock, buf, strlen (buf));
-		close (tport[*port].tcan[can].sock);
-		clear_can (*port, can);
-		return (FALSE);
-	}
-
-	if (res & WRITE_EVENT)
-	{
-		/* Can write to the socket... Unused */
-	}
-
-	if (res & EXCEPT_EVENT)
-	{
-		if (tport[*port].tcan[can].event == CONN_EVENT)
+		if ((tport[*port].tcan[can].sock == -1) && (tport[*port].tcan[can].state != DISCONNECT))
 		{
-			/* Appel sortant connecte */
-
-			/* Le host distant a ete connecte.
-			   sprintf(buffer, "*** Connected to %s-%d\r", 
-			   tcan[can].callsign.call, tcan[can].callsign.num);
-			   in_buf(voie, buffer, strlen(buffer)); */
-
-			/* if (tcan[can].lgcall)
-				write (tcan[can].sock, tcan[can].call, tcan[can].lgcall); */
+			sprintf (buffer, "(%d) DISCONNECTED fm TCP", can);
 			
-			/* Connexion a la BBS... */
-			sprintf (buffer, "(%d) CONNECTED to %s-%d",
-					 can, tport[*port].tcan[can].callsign.call, tport[*port].tcan[can].callsign.num);
+/*			fprintf (stderr, "(%d) DISCONNECTED fm TCP\n", can);*/
 
-			if (p_port[*port].typort == TYP_ETH)
-				tport[*port].tcan[can].state = SENDCALL;
-			else
-				tport[*port].tcan[can].state = CONNECTED;
-
-			tport[*port].tcan[can].nb_try = 0;
-			tport[*port].tcan[can].timeout = 0L;
+			tport[*port].tcan[can].state = DISCONNECT;
+			clear_can (*port, can);
 			*len = strlen (buffer);
 			*cmd = COMMAND;
 			*canal = can;
 			return (TRUE);
 		}
-	}
 
-#define LGTCP 1100
+		/* Canal de communication */
+		res = s_status (&tport[*port].tcan[can]);
 
-	if ((res & QUEUE_EVENT) || (res & READ_EVENT))
-	{
-		int nb = 0;
-		int i;
-
-		if (tport[*port].tcan[can].sock == -1)
+		if (res & TIME_EVENT)
 		{
-			printf ("read on invalid socket\n");
+			sprintf (buf, "Timeout, disconnected !\r\n");
+/*			fprintf (stderr, "Timeout, disconnected !\n");*/
+	
+			write (tport[*port].tcan[can].sock, buf, strlen (buf));
+			close (tport[*port].tcan[can].sock);
+			clear_can (*port, can);
 			return (FALSE);
 		}
 
-		/* Alloue le buffer si necessaire */
-		if (tport[*port].tcan[can].lbuf == NULL)
+		if (res & WRITE_EVENT)
 		{
-			tport[*port].tcan[can].lbuf = calloc (LGTCP, 1);
-			tport[*port].tcan[can].lpos = 0;
-			tport[*port].tcan[can].lqueue = 0;
-			tport[*port].tcan[can].nb_ret = 0;
+			/* Can write to the socket... Unused */
 		}
 
-		if (res & READ_EVENT)
+		if (res & EXCEPT_EVENT)
 		{
-			/* Reste de la place ds le buffer ? */
-			nb = ((LGTCP - tport[*port].tcan[can].lqueue) > 256) ? 256 : LGTCP - tport[*port].tcan[can].lqueue;
-			if (nb)
+			if (tport[*port].tcan[can].event == CONN_EVENT)
 			{
-				nb = read (tport[*port].tcan[can].sock, buffer, nb);
-				if ((nb == 0) || ((nb == -1) && (errno == ENOTCONN)))
-				{
-					/* Deconnection */
-					sprintf (buffer, "(%d) DISCONNECTED fm TCP", can);
-					close (tport[*port].tcan[can].sock);
-					clear_can (*port, can);
-					*len = strlen (buffer);
-					*cmd = COMMAND;
-					*canal = can;
-					return (TRUE);
-				}
-				else if (nb == -1)
-				{
-					printf ("errno = %d\n", errno);
-					perror ("read");
-					return (FALSE);
-				}
-			}
-		}
+				/* Appel sortant connecte */
 
-		{
-			int process;
-			int pos;
-			int lg;
-			char *ptr;
-			char *address;
-			int addr_len;
-			struct sockaddr_in sock_addr;
+				/* Le host distant a ete connecte.
+				   sprintf(buffer, "*** Connected to %s-%d\r", 
+				   tcan[can].callsign.call, tcan[can].callsign.num);
+				   in_buf(voie, buffer, strlen(buffer)); */
 
-			if (nb)
-			{
-				nb = tcp_trame (*port, can, buffer, nb);
+				/* if (tcan[can].lgcall)
+					write (tcan[can].sock, tcan[can].call, tcan[can].lgcall); */
 
-				if (nb == 0)
-					return (FALSE);
-			}
+				/* Connexion a la BBS... */
+				sprintf (buffer, "(%d) CONNECTED to %s-%d",
+						 can, tport[*port].tcan[can].callsign.call, tport[*port].tcan[can].callsign.num);
+				
+/*				fprintf (stderr, "(%d) CONNECTED fm tcp to %s-%d\n",
+						 can, tport[*port].tcan[can].callsign.call, tport[*port].tcan[can].callsign.num);*/
 
-			pos = tport[*port].tcan[can].lpos + tport[*port].tcan[can].lqueue;
-			if (pos > LGTCP)
-				pos -= LGTCP;
-
-			for (i = 0; i < nb; i++)
-			{
-				if (tport[*port].tcan[can].lqueue > (LGTCP - 10))
-				{
-					++tport[*port].tcan[can].nb_ret;
-					break;
-				}
-
-				tport[*port].tcan[can].lbuf[pos] = buffer[i];
-				if (++pos == LGTCP)
-					pos = 0;
-
-				++tport[*port].tcan[can].lqueue;
-
-				if (buffer[i] == '\r')
-				{
-					++tport[*port].tcan[can].nb_ret;
-				}
-			}
-
-			nb = tport[*port].tcan[can].lqueue;
-
-			tport[*port].tcan[can].timeout = time (NULL) + 120L;
-			process = (tport[*port].tcan[can].nb_ret > 0);
-
-			switch (tport[*port].tcan[can].state)
-			{
-			case SENDCALL:
-				lg = tcp_getline (*port, can, buffer);
-				if (lg == 0)
-					return 0;
-
-				buffer[lg] = '\0';
-				if (strstr(buffer, "allsig"))
-				{
-					write(tport[*port].tcan[can].sock, tport[*port].tcan[can].call, tport[*port].tcan[can].lgcall);
-					tport[*port].tcan[can].state = CONNECTED;
-					tport[*port].tcan[can].lgcall = 0;
-					return (TRUE);
-				}
-				break;
-			case WAITINGCALL:
-				if (!process)
-					return (FALSE);
-
-				if (!tcp_getline (*port, can, buffer))
-					return 0;
-
-				sup_ln (strupr (buffer));
-
-				addr_len = sizeof (sock_addr);
-				if ((getpeername(tport[*port].tcan[can].sock, (struct sockaddr *)&sock_addr, &addr_len) == 0) && (sock_addr.sin_family == AF_INET))
-					address = inet_ntoa(sock_addr.sin_addr);
+				if (p_port[*port].typort == TYP_ETH)
+					tport[*port].tcan[can].state = SENDCALL;
 				else
-					address = NULL;
+					tport[*port].tcan[can].state = CONNECTED;
 
-				switch (tcp_check_call (*port, can, buffer, address))
+				tport[*port].tcan[can].nb_try = 0;
+				tport[*port].tcan[can].timeout = 0L;
+				*len = strlen (buffer);
+				*cmd = COMMAND;
+				*canal = can;
+				return (TRUE);
+			}
+		}
+
+#define LGTCP 1100
+
+		if ((res & QUEUE_EVENT) || (res & READ_EVENT))
+		{
+			int nb = 0;
+			int i;
+
+			if (tport[*port].tcan[can].sock == -1)
+			{
+				printf ("read on invalid socket\n");
+				return (FALSE);
+			}
+
+			/* Alloue le buffer si necessaire */
+			if (tport[*port].tcan[can].lbuf == NULL)
+			{
+				tport[*port].tcan[can].lbuf = calloc (LGTCP, 1);
+				tport[*port].tcan[can].lpos = 0;
+				tport[*port].tcan[can].lqueue = 0;
+				tport[*port].tcan[can].nb_ret = 0;
+			}
+
+			if (res & READ_EVENT)
+			{
+				/* Reste de la place ds le buffer ? */
+				nb = ((LGTCP - tport[*port].tcan[can].lqueue) > 256) ? 256 : LGTCP - tport[*port].tcan[can].lqueue;
+				if (nb)
 				{
-				case 0:
-					if (++tport[*port].tcan[can].nb_try > 3)
+					nb = read (tport[*port].tcan[can].sock, buffer, nb);
+					if ((nb == 0) || ((nb == -1) && (errno == ENOTCONN)))
 					{
-						sprintf (buf, "Callsign error, disconnected !\r\n");
-						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+						/* Deconnection */
+						sprintf (buffer, "(%d) DISCONNECTED fm TCP", can);
+/*						fprintf (stderr, "(%d) DISCONNECTED fm TCP\n", can);*/
+						
 						close (tport[*port].tcan[can].sock);
-						tport[*port].tcan[can].sock = -1;
+						clear_can (*port, can);
+						*len = strlen (buffer);
+						*cmd = COMMAND;
+						*canal = can;
+						return (TRUE);
 					}
-					else
+					else if (nb == -1)
 					{
-						char buf[80];
+						printf ("errno = %d\n", errno);
+						perror ("read");
+						return (FALSE);
+					}
+				}
+			}
 
-						sprintf (buf, "Invalid callsign \"%s\" !\r\n", buffer);
-						write (tport[*port].tcan[can].sock, buf, strlen (buf));
-						sprintf (buf, "Callsign : ");
-						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+			{
+				int process;
+				int pos;
+				int lg;
+				char *ptr;
+				char *address;
+				unsigned addr_len;
+				struct sockaddr_in sock_addr;
+
+				if (nb)
+				{
+					nb = tcp_trame (*port, can, buffer, nb);
+
+					if (nb == 0)
+						return (FALSE);
+				}
+
+				pos = tport[*port].tcan[can].lpos + tport[*port].tcan[can].lqueue;
+				if (pos > LGTCP)
+					pos -= LGTCP;
+
+				for (i = 0; i < nb; i++)
+				{
+					if (tport[*port].tcan[can].lqueue > (LGTCP - 10))
+					{
+						++tport[*port].tcan[can].nb_ret;
+						break;
+					}
+
+					tport[*port].tcan[can].lbuf[pos] = buffer[i];
+					if (++pos == LGTCP)
+						pos = 0;
+
+					++tport[*port].tcan[can].lqueue;
+
+					if (buffer[i] == '\r')
+					{
+						++tport[*port].tcan[can].nb_ret;
+					}
+				}
+
+				nb = tport[*port].tcan[can].lqueue;
+
+				tport[*port].tcan[can].timeout = time (NULL) + 120L;
+				process = (tport[*port].tcan[can].nb_ret > 0);
+
+				switch (tport[*port].tcan[can].state)
+				{
+				case SENDCALL:
+					lg = tcp_getline (*port, can, buffer);
+					if (lg == 0)
+						return 0;
+
+					buffer[lg] = '\0';
+					if (strstr(buffer, "allsig"))
+					{
+						write(tport[*port].tcan[can].sock, tport[*port].tcan[can].call, tport[*port].tcan[can].lgcall);
+						tport[*port].tcan[can].state = CONNECTED;
+						tport[*port].tcan[can].lgcall = 0;
+						return (TRUE);
 					}
 					break;
-				case 1:
-					{
-						info buf_info;
-						FILE *fptr;
-						unsigned coord;
+				case WAITINGCALL:
+					if (!process)
+						return (FALSE);
 
-						if ((coord = chercoord (tport[*port].tcan[can].callsign.call)) == 0xffff)
+					if (!tcp_getline (*port, can, buffer))
+						return 0;
+
+					sup_ln (strupr (buffer));
+
+					addr_len = sizeof (sock_addr);
+					if ((getpeername(tport[*port].tcan[can].sock, (struct sockaddr *)&sock_addr, &addr_len) == 0) && (sock_addr.sin_family == AF_INET))
+						address = inet_ntoa(sock_addr.sin_addr);
+					else
+						address = NULL;
+
+					switch (tcp_check_call (*port, can, buffer, address))
+					{
+					case 0:
+						if (++tport[*port].tcan[can].nb_try > 3)
 						{
+							sprintf (buf, "Callsign error, disconnected !\r\n");
+/*							fprintf (stderr, "Callsign error, disconnected !\n");*/
+							write (tport[*port].tcan[can].sock, buf, strlen (buf));
 							close (tport[*port].tcan[can].sock);
 							tport[*port].tcan[can].sock = -1;
-							break;
-						}
-
-						fptr = ouvre_nomenc ();
-						fseek (fptr, (long) coord * sizeof (info), 0);
-						fread ((char *) &buf_info, sizeof (info), 1, fptr);
-						ferme (fptr, 11);
-
-						if (!MOD (buf_info.flags))
-						{
-							read_only_alert (*port, can);
-							tport[*port].tcan[can].state = READONLY;
-						}
-						else
-						{
-							sprintf (buf, "Password : ");
-							write (tport[*port].tcan[can].sock, buf, strlen (buf));
-							tport[*port].tcan[can].state = WAITINGPASS;
-							tport[*port].tcan[can].nb_try = 0;
-						}
-					}
-					break;
-				case 2:
-					if (++tport[*port].tcan[can].nb_try > 3)
-					{
-						sprintf (buf, "Callsign error, disconnected !\r\n");
-						write (tport[*port].tcan[can].sock, buf, strlen (buf));
-						close (tport[*port].tcan[can].sock);
-						tport[*port].tcan[can].sock = -1;
-					}
-					else
-					{
-						if (p_port[*port].moport & 0x40)
-						{
-							read_only_alert (*port, can);
-							tport[*port].tcan[can].state = READONLY;
 						}
 						else
 						{
 							char buf[80];
 
-							sprintf (buf, "Unregistered callsign \"%s\" !\r\n", buffer);
+							buffer[20] = '\0';
+							sprintf (buf, "Invalid callsign \"%s\" !\r\n", buffer);
+/*							fprintf (stderr, "Invalid callsign \"%s\" !\n", buffer);*/
 							write (tport[*port].tcan[can].sock, buf, strlen (buf));
 							sprintf (buf, "Callsign : ");
+							
+/*							fprintf (stderr, "Callsign : ");*/
+							
 							write (tport[*port].tcan[can].sock, buf, strlen (buf));
 						}
-					}
-					break;
-				case 5:
-					sprintf (buffer, "(%d) CONNECTED to %s-%d",
-							 can, tport[*port].tcan[can].callsign.call,
-							 tport[*port].tcan[can].callsign.num);
-					tport[*port].tcan[can].state = CONNECTED;
-					tport[*port].tcan[can].nb_try = 0;
-					tport[*port].tcan[can].timeout = 0L;
-					*len = strlen (buffer);
-					*cmd = COMMAND;
-					*canal = can;
-					return (TRUE);
-				}
-				break;
-
-			case WAITINGPASS:
-				if (!process)
-					return (FALSE);
-
-				if (!tcp_getline (*port, can, buffer))
-					return 0;
-
-				sup_ln (buffer);
-				if (tcp_check_pass (*port, can, buffer))
-				{
-					sprintf (buf, "\r\nLogon Ok. Type NP to change password.\r\n\r\n");
-					write (tport[*port].tcan[can].sock, buf, strlen (buf));
-					sprintf (buffer, "(%d) CONNECTED to %s-%d",
-							 can, tport[*port].tcan[can].callsign.call,
-							 tport[*port].tcan[can].callsign.num);
-					tport[*port].tcan[can].state = CONNECTED;
-					tport[*port].tcan[can].nb_try = 0;
-					tport[*port].tcan[can].timeout = 0L;
-					*len = strlen (buffer);
-					*cmd = COMMAND;
-					*canal = can;
-					return (TRUE);
-				}
-				else
-				{
-					if (++tport[*port].tcan[can].nb_try > 3)
-					{
-						if (p_port[*port].moport & 0x40)
+						break;
+					case 1:
 						{
-							read_only_alert (*port, can);
-							tport[*port].tcan[can].state = READONLY;
+							info buf_info;
+							FILE *fptr;
+							unsigned coord;
+
+							if ((coord = chercoord (tport[*port].tcan[can].callsign.call)) == 0xffff)
+							{
+								close (tport[*port].tcan[can].sock);
+								tport[*port].tcan[can].sock = -1;
+								break;
+							}
+
+							fptr = ouvre_nomenc ();
+							fseek (fptr, (long) coord * sizeof (info), 0);
+							fread ((char *) &buf_info, sizeof (info), 1, fptr);
+							ferme (fptr, 11);
+
+							if (!MOD (buf_info.flags))
+							{
+								read_only_alert (*port, can);
+								tport[*port].tcan[can].state = READONLY;
+							}
+							else
+							{
+								sprintf (buf, "Password : ");
+								write (tport[*port].tcan[can].sock, buf, strlen (buf));
+								tport[*port].tcan[can].state = WAITINGPASS;
+								tport[*port].tcan[can].nb_try = 0;
+							}
 						}
-						else
+						break;
+					case 2:
+						if (++tport[*port].tcan[can].nb_try > 3)
 						{
-							sprintf (buf, "Password error, disconnected !\r\n");
+							sprintf (buf, "Callsign error, disconnected !\r\n");
+/*							fprintf (stderr, "Callsign error, disconnected !\n");*/
 							write (tport[*port].tcan[can].sock, buf, strlen (buf));
 							close (tport[*port].tcan[can].sock);
 							tport[*port].tcan[can].sock = -1;
 						}
+						else
+						{
+							if (p_port[*port].moport & 0x40)
+							{
+								read_only_alert (*port, can);
+								tport[*port].tcan[can].state = READONLY;
+							}
+							else
+							{
+								char buf[80];
+
+								sprintf (buf, "Unregistered callsign \"%s\" !\r\n", buffer);
+								write (tport[*port].tcan[can].sock, buf, strlen (buf));
+								sprintf (buf, "For registration send message to SYSOP.\r\n\n");
+								write (tport[*port].tcan[can].sock, buf, strlen (buf));
+								sprintf (buf, "Callsign : ");
+								write (tport[*port].tcan[can].sock, buf, strlen (buf));
+							}
+						}
+						break;
+					case 5:
+						sprintf (buffer, "(%d) CONNECTED to %s-%d",
+								 can, tport[*port].tcan[can].callsign.call,
+								 tport[*port].tcan[can].callsign.num);
+/*						fprintf (stderr, "(%d) CONNECTED to %s-%d\n",
+								 can, tport[*port].tcan[can].callsign.call,
+								 tport[*port].tcan[can].callsign.num);*/
+						tport[*port].tcan[can].state = CONNECTED;
+						tport[*port].tcan[can].nb_try = 0;
+						tport[*port].tcan[can].timeout = 0L;
+						*len = strlen (buffer);
+						*cmd = COMMAND;
+						*canal = can;
+						return (TRUE);
+					}
+					break;
+
+				case WAITINGPASS:
+					if (!process)
+						return (FALSE);
+
+					if (!tcp_getline (*port, can, buffer))
+						return 0;
+
+					sup_ln (buffer);
+					if (tcp_check_pass (*port, can, buffer))
+					{
+						sprintf (buf, "\r\nLogon Ok. Type NP to change password.\r\n\r\n");
+						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+						sprintf (buffer, "(%d) CONNECTED to %s-%d",
+								 can, tport[*port].tcan[can].callsign.call,
+								 tport[*port].tcan[can].callsign.num);
+						tport[*port].tcan[can].state = CONNECTED;
+						tport[*port].tcan[can].nb_try = 0;
+						tport[*port].tcan[can].timeout = 0L;
+						*len = strlen (buffer);
+						*cmd = COMMAND;
+						*canal = can;
+						return (TRUE);
 					}
 					else
 					{
-						char buf[80];
+						if (++tport[*port].tcan[can].nb_try > 3)
+						{
+							if (p_port[*port].moport & 0x40)
+							{
+								read_only_alert (*port, can);
+								tport[*port].tcan[can].state = READONLY;
+							}
+							else
+							{
+								sprintf (buf, "Password error, disconnected !\r\n");
+								write (tport[*port].tcan[can].sock, buf, strlen (buf));
+								close (tport[*port].tcan[can].sock);
+								tport[*port].tcan[can].sock = -1;
+							}
+						}
+						else
+						{
+							char buf[80];
 
-						sprintf (buf, "Password error !\r\nPassword : ");
-						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+							sprintf (buf, "Password error !\r\nPassword : ");
+							write (tport[*port].tcan[can].sock, buf, strlen (buf));
+						}
 					}
-				}
-				return (FALSE);
-
-			case READONLY:
-				if (!process)
 					return (FALSE);
 
-				if (!tcp_getline (*port, can, buffer))
-					return 0;
+				case READONLY:
+					if (!process)
+						return (FALSE);
 
-				if (toupper (*buffer) == 'Y')
-				{
-					/* Read-Only mode accepted */
-					sprintf (buf, "\r\nLogon Ok. You have a read-only access.\r\n\r\n");
-					write (tport[*port].tcan[can].sock, buf, strlen (buf));
-					sprintf (buffer, "(%d) READONLY to %s-%d",
-							 can, tport[*port].tcan[can].callsign.call,
-							 tport[*port].tcan[can].callsign.num);
-					tport[*port].tcan[can].state = CONNECTED;
-					tport[*port].tcan[can].nb_try = 0;
-					tport[*port].tcan[can].timeout = 0L;
-					*len = strlen (buffer);
-					*cmd = COMMAND;
+					if (!tcp_getline (*port, can, buffer))
+						return 0;
+
+					if (toupper (*buffer) == 'Y')
+					{
+						/* Read-Only mode accepted */
+						sprintf (buf, "\r\nLogon Ok. You have a read-only access.\r\n\r\n");
+						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+						sprintf (buffer, "(%d) READONLY to %s-%d",
+								 can, tport[*port].tcan[can].callsign.call,
+								 tport[*port].tcan[can].callsign.num);
+						tport[*port].tcan[can].state = CONNECTED;
+						tport[*port].tcan[can].nb_try = 0;
+						tport[*port].tcan[can].timeout = 0L;
+						*len = strlen (buffer);
+						*cmd = COMMAND;
+						*canal = can;
+						return (TRUE);
+					}
+					else
+					{
+						sprintf (buf, "Callsign : ");
+						write (tport[*port].tcan[can].sock, buf, strlen (buf));
+						tport[*port].tcan[can].state = WAITINGCALL;
+					}
+					break;
+
+				default:
+					pos = tport[*port].tcan[can].lpos;
+					ptr = tport[*port].tcan[can].lbuf;
+					for (i = 0; i < tport[*port].tcan[can].lqueue; i++)
+					{
+						buffer[i] = ptr[pos];
+						if (++pos == LGTCP)
+							pos = 0;
+					}
+					*len = tport[*port].tcan[can].lqueue;
+					*cmd = DATA;
 					*canal = can;
+					tport[*port].tcan[can].nb_ret = 0;
+					tport[*port].tcan[can].lpos = 0;
+					tport[*port].tcan[can].lqueue = 0;
+					tport[*port].tcan[can].timeout = 0L;
 					return (TRUE);
 				}
-				else
-				{
-					sprintf (buf, "Callsign : ");
-					write (tport[*port].tcan[can].sock, buf, strlen (buf));
-					tport[*port].tcan[can].state = WAITINGCALL;
-				}
-				break;
-
-			default:
-				pos = tport[*port].tcan[can].lpos;
-				ptr = tport[*port].tcan[can].lbuf;
-				for (i = 0; i < tport[*port].tcan[can].lqueue; i++)
-				{
-					buffer[i] = ptr[pos];
-					if (++pos == LGTCP)
-						pos = 0;
-				}
-				*len = tport[*port].tcan[can].lqueue;
-				*cmd = DATA;
-				*canal = can;
-				tport[*port].tcan[can].nb_ret = 0;
-				tport[*port].tcan[can].lpos = 0;
-				tport[*port].tcan[can].lqueue = 0;
-				tport[*port].tcan[can].timeout = 0L;
-				return (TRUE);
 			}
 		}
 	}
@@ -915,8 +954,11 @@ int cls_tcp (int port)
 
 static int stop_cnx (int port)
 {
-	close(p_port[port].fd);
-	p_port[port].fd = 0;
+	if (p_port[port].fd) /* Prevent closing of 0 */
+	{
+		close(p_port[port].fd);
+		p_port[port].fd = 0;
+	}
 	return 1;
 }
 
@@ -1045,7 +1087,7 @@ static int tcp_trame (int port, int canal, char *data, int len)
 			{
 				char buf[80];
 
-				printf ("%02x...\n", carac);
+/*				printf ("%02x...\n", carac);*/
 				switch (tport[port].tcan[canal].ial[1])
 				{
 				case WILL:
@@ -1206,14 +1248,16 @@ static int tcp_snd_dt (int port, int canal, char *buffer, int len)
 	}
 
 	lg = write (tport[port].tcan[canal].sock, buf, nb);
-	if (nb == -1)
+	if (lg == -1)
 	{
-		printf ("Error %d on socket %d\n", errno, tport[port].tcan[canal].sock);
-		perror ("write on socket");
+/*		printf ("tcp_snd_dt() Error %d on socket %d\n", errno, tport[port].tcan[canal].sock); */
+/*		perror ("tcp_snd_dt() write on socket");*/
+		return (FALSE);
 	}
 	else if (lg < nb)
 	{
-		printf ("Cannot write %d bytes on socket %d\n", nb - lg, tport[port].tcan[canal].sock);
+/*		printf ("tcp_snd_dt() Cannot write %d bytes on socket %d\n", nb - lg, tport[port].tcan[canal].sock); */
+		return (FALSE);
 	}
 	return (TRUE);
 }
@@ -1318,13 +1362,13 @@ static int tcp_connect (int port, char *commande, int can)
 
 		if (!find (tport[port].tcan[can].callsign.call))
 		{
-			fprintf (stderr, "connect : invalid callsign %s\n", indic);
+/*			fprintf (stderr, "connect : invalid callsign %s\n", indic);*/
 			return (0);
 		}
 
 		if (tcp_add[0] == '\0')
 		{
-			fprintf (stderr, "connect : tcp address missing\n");
+/*			fprintf (stderr, "connect : tcp address missing\n");*/
 			return (0);
 		}
 		
@@ -1353,14 +1397,15 @@ static int tcp_connect (int port, char *commande, int can)
 		if (errno != EINPROGRESS)
 		{
 			printf ("\n");
-			perror ("connect");
+	/*		perror ("connect");*/
+/*	printf ("*** Cannot connect %s canal %d\n", commande, can);*/
 			clear_can (port, can);
 			close (fd);
 			return (0);
 		}
 	}
 
-	printf ("*** Connect in progress %s canal %d\n", commande, can);
+/*	printf ("*** Connect in progress %s canal %d\n", commande, can);*/
 
 	tport[port].tcan[can].sock = fd;
 	tport[port].tcan[can].state = CPROGRESS;
@@ -1401,7 +1446,7 @@ static int s_status (tcan_t * can)
 	fd_set tcp_excep;
 	struct timeval to;
 
-	if (can->sock == -1)
+	if (can->sock <= 0) /* Was -1.  Sock=0 during housekeeping.  Cause of select errors */
 		return (0);
 
 	if ((can->timeout) && (can->timeout < time (NULL)))
@@ -1488,6 +1533,8 @@ static int s_free (tcan_t * can)
 
 static void clear_can (int port, int canal)
 {
+/*	fprintf (stderr, "drv_tcp : clear_can() port %d canal %d\n", port, canal);*/
+
 	if (tport[port].tcan[canal].lbuf)
 		free (tport[port].tcan[canal].lbuf);
 	memset (&tport[port].tcan[canal], 0, sizeof (tcan_t));
@@ -1609,7 +1656,7 @@ static int rcv_tcp_ui(int port, char *buffer, int *len, ui_header * ui)
 	fd_set tcp_read;
 	struct timeval to;
 	struct sockaddr_in sock_addr;
-	int addr_len = sizeof (sock_addr);
+	unsigned addr_len = sizeof (sock_addr);
 	char buf[1024];
 	char *ptr;
 	char *p;
