@@ -51,6 +51,7 @@ extern char _video[];
 void initialisations (void)
 {
 	int bbs_init = 1;
+	fprintf (stderr, "\nMSDOS defined  init.c INITIALISATIONS\n");
 
 	while (!step_initialisations (bbs_init))
 		++bbs_init;
@@ -66,6 +67,8 @@ int step_initialisations (int niveau)
 
 	InitText ("");
 
+/*	fprintf (stderr, "FBB step_initialisations niveau:%d\n",niveau);*/
+		
 	switch (niveau)
 	{
 
@@ -103,6 +106,7 @@ int step_initialisations (int niveau)
 		editor_request = 0;
 		errno = 0;
 		fast_fwd = 1;
+		lastaff = -1;
 		reply = 0;
 		snd_io = 0;
 		test_message = 2;
@@ -140,9 +144,12 @@ int step_initialisations (int niveau)
 		nb_error = 0;
 		temp_sec = SECONDE;
 		d_blanc = 0;
-		include_size = p_forward = 0;
+		include_size = 0;
+		p_forward = 0;
 		time_include = NULL;
-		t_appel = t_bbs = mem_alloue = 0L;
+		mem_alloue = 0L;
+		t_bbs = 0L;
+		t_appel = 0L;
 		hour_time = -1;
 		t_iliste.suiv = NULL;
 		tete_fwd = NULL;
@@ -190,10 +197,19 @@ int step_initialisations (int niveau)
 		init_tpstat ();
 		free_mem ();
 
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("RS232 ports set-up            \r\n");
 #else
 		cprintf ("Initialisation des ports RS232\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("RS232 ports set-up            \n");
+#else
+		cprintf ("Initialisation des ports RS232\n");
+#endif
 #endif
 		init_watchdog (watchport);
 		initport ();
@@ -201,10 +217,19 @@ int step_initialisations (int niveau)
 
 	case 4:
 		initcom ();
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("TNC set-up            \r\n");
 #else
 		cprintf ("Initialisation des TNC\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("TNC set-up            \n");
+#else
+		cprintf ("Initialisation des TNC\n");
+#endif
 #endif
 		inittnc ();
 		return 0;
@@ -217,10 +242,19 @@ int step_initialisations (int niveau)
 		return 0;
 
 	case 6:
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("BID set-up            \r\n");
 #else
 		cprintf ("Initialisation des BID\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("BID set-up            \n");
+#else
+		cprintf ("Initialisation des BID\n");
+#endif
 #endif
 		cree_bid ();
 		free_mem ();
@@ -243,10 +277,19 @@ int step_initialisations (int niveau)
 		else
 			h_ok = 0;
 		free_mem ();
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("Files set-up complete           \r\n");
 #else
 		cprintf ("Fin des initialisations Fichiers\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("Files set-up complete           \n");
+#else
+		cprintf ("Fin des initialisations Fichiers\n");
+#endif
 #endif
 		return 0;
 
@@ -254,10 +297,19 @@ int step_initialisations (int niveau)
 		fwd_file = NULL;
 		fwd_size = 0;
 
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("FORWARD set-up           \r\n");
 #else
 		cprintf ("Initialisation du forward\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("FORWARD set-up           \n");
+#else
+		cprintf ("Initialisation du forward\n");
+#endif
 #endif
 		init_buf_fwd ();
 		init_buf_swap ();
@@ -277,15 +329,25 @@ int step_initialisations (int niveau)
 		init_hold ();
 		init_pfh();
 		load_themes ();
+#ifdef __FBBDOS__
 #ifdef ENGLISH
 		cprintf ("Set-up complete        \r\n");
 #else
 		cprintf ("Fin des initialisations\r\n");
+#endif
+#endif
+#ifdef __linux__
+#ifdef ENGLISH
+		cprintf ("Set-up complete        \n");
+#else
+		cprintf ("Fin des initialisations\n");
+#endif
 #endif
 		vlang = 0;
 		com_error = old_com_error = 0;
 		aff_ind_console ();
 		free_mem ();
+		aff_date ();
 		aff_heure ();
 		fin_io ();
 		canaff = v_aff;
@@ -296,7 +358,7 @@ int step_initialisations (int niveau)
 		if (*BBS_UP)
 		{
 			char *pptr = BBS_UP;
-#ifdef __LINUX__
+#ifdef __linux__
 			call_nbdos (&pptr, 1, NO_REPORT_MODE, NULL, TOOLDIR, NULL);
 #else
 			call_nbdos (&pptr, 1, NO_REPORT_MODE, NULL, NULL, NULL);
@@ -353,7 +415,9 @@ static void start_bbs (void)
 	}
 
 	test_disque ();
-	port_log (0, 0, 'S', "A *** BBS Online");
+ 	sprintf (buffer, "A *** BBS Online (%s)", version());
+ 	port_log (0, 0, 'S', buffer);
+/*	port_log (0, 0, 'S', "A *** BBS Online");*/
 	fin_io ();
 
 	start_tasks ();
@@ -362,7 +426,7 @@ static void start_bbs (void)
 	dde_wp_serv = 1;
 
 
-	/* Ammorce les TNCs en mode DED */
+	/* Amorce les TNCs en mode DED */
 	for (nb = 0; nb < NBPORT; nb++)
 	{
 		int i;
@@ -528,12 +592,12 @@ void init_voie (int voie)
 
 	svoie[voie] = vptr = (Svoie *) m_alloue (sizeof (Svoie));
 	time_yapp[voie] = -1;
+	vptr->timout = time_n;
 	init_timout (voie);
 	vptr->msg_held = 0;
 	vptr->rzsz_pid = -1;
 	vptr->temp1 = vptr->mess_recu = 1;
 	vptr->fbb = bin_fwd;
-	vptr->timout = time_n;
 	/* vptr->wp = */ vptr->clock = '\0';
 	vptr->ret = 0;	
 	vptr->sid = vptr->aut_nc = vptr->ind_mess = vptr->warning = 0;
@@ -543,7 +607,8 @@ void init_voie (int voie)
 	vptr->sr_mem = vptr->memoc = vptr->nb_err = 0;
 	vptr->niv1 = vptr->niv2 = vptr->niv3 = 0;
 	vptr->maj_ok = vptr->conf = vptr->dde_marche = 0;
-	vptr->kiss = vptr->ch_mon = vptr->cross_connect = -1;
+	vptr->groupe = vptr->kiss = vptr->ch_mon = vptr->cross_connect = -1;
+	vptr->cur_bull = -1L;
 	vptr->localmode = vptr->binary = vptr->sta.ret = vptr->sta.ack = 0;
 	vptr->type_yapp = 0;
 	vptr->maxbuf = 8;
@@ -610,6 +675,7 @@ void lit_appel (void)
 		fread (&p_forward, sizeof (short), 1, fptr);
 		fread (&sed, sizeof (short), 1, fptr);
 		fread (&aff_inexport, sizeof (short), 1, fptr);
+		fread (&aff_popsmtp, sizeof (short), 1, fptr);
 
 		fclose (fptr);
 	}
@@ -619,7 +685,7 @@ void lit_appel (void)
 	if (separe > h_screen - 4)
 		separe = h_screen - 4;
 	/*  printf("%d %d %d %d %d\n", bip, ok_tell, ok_aff, separe, doub_fen) ; */
-#if defined(__WINDOWS__) || defined(__LINUX__)
+#if defined(__WINDOWS__) || defined(__linux__)
 	maj_menu_options ();
 #endif
 }
@@ -656,9 +722,9 @@ void cree_stat (void)
 {
 	FILE *fptr;
 
-	if ((fptr = fopen (d_disque ("STATIS.DAT"), "wb")) == NULL)
+	if ((fptr = fopen (d_disque ("statis.dat"), "wb")) == NULL)
 	{
-		fbb_error (ERR_CREATE, d_disque ("STATIS.DAT"), 0);
+		fbb_error (ERR_CREATE, d_disque ("statis.dat"), 0);
 	}
 	fclose (fptr);
 }
@@ -754,16 +820,32 @@ static void initarbre (void)
 	FILE *fptr;
 	bloc_indic *bptr;
 
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("Callsign set-up                  \n");
+#else
+	cprintf ("Initialisation de la nomenclature\n");
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("Callsign set-up                  \r\n");
 #else
 	cprintf ("Initialisation de la nomenclature\r\n");
+#endif
 #endif
 	deb_io ();
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("Callsigns set-up             \n");
+#else
+	cprintf ("Initialisation des indicatifs\n");
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("Callsigns set-up             \r\n");
 #else
 	cprintf ("Initialisation des indicatifs\r\n");
+#endif
 #endif
 	rinfo = 0;
 
@@ -789,7 +871,7 @@ static void initarbre (void)
 				bptr = bptr->suiv;
 				offset = 0;
 			}
-#ifdef __LINUX__
+#ifdef __linux__
 			if ((i++ % 50) == 0)
 			{
 				InitText (itoa (i, buf, 10));
@@ -815,8 +897,12 @@ static void initarbre (void)
 	}
 #ifdef __WINDOWS__
 	InitText (itoa (i, buf, 10));
+#else
+#ifdef __linux__
+	cprintf ("%-6s\n", buf2.indic.call);
 #else
 	cprintf ("%-6s\r", buf2.indic.call);
+#endif
 #endif
 	ferme (fptr, 4);
 	fin_io ();
@@ -917,10 +1003,18 @@ static void initmessage (void)
 	pos = nbfwd = 0;
 	ptr_fwd = tete_fwd = cree_bloc_fwd (NULL);
 
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("Message set-up             \n");
+#else
+	cprintf ("Initialisation des messages\n");
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("Message set-up             \r\n");
 #else
 	cprintf ("Initialisation des messages\r\n");
+#endif
 #endif
 	deb_io ();
 	nbmess = 0;
@@ -928,10 +1022,18 @@ static void initmessage (void)
 	ouvre_dir ();
 	read_dir (rmess++, &bufdir);
 	nomess = bufdir.numero;
+#ifdef __linux__
 #ifdef ENGLISH
-	cprintf ("Next message %ld    \r\n", nomess + 1);
+	cprintf ("Next message %ld  \r\n", nomess + 1);
+#else
+	cprintf ("Prochain message %ld\n", nomess + 1);
+#endif
+#else
+#ifdef ENGLISH
+	cprintf ("Next message %ld   \r\n", nomess + 1,);
 #else
 	cprintf ("Prochain message %ld\r\n", nomess + 1);
+#endif
 #endif
 
 	bptr = tete_dir = new_bloc_mess ();
@@ -940,7 +1042,7 @@ static void initmessage (void)
 	{
 		if (bufdir.type)
 		{
-#ifdef __LINUX__
+#ifdef __linux__
 			if ((i++ % 50) == 0)
 			{
 				InitText (itoa (i, buf, 10));
@@ -998,17 +1100,32 @@ static void initmessage (void)
 
 #ifdef __WINDOWS__
 	InitText (itoa (i, buf, 10));
+#else
+#ifdef __linux__
+	if (bufdir.type)
+	{
+		cprintf ("%ld %-6s %d\n", bufdir.numero, bufdir.exped, nbfwd);
+	}
 #else
 	if (bufdir.type)
 	{
 		cprintf ("%ld %-6s %d\r", bufdir.numero, bufdir.exped, nbfwd);
 	}
+#endif
 #endif
 	ferme_dir ();
 	fin_io ();
+#ifdef __linux__
+#ifdef ENGLISH
+	cprintf ("End - %d forward(s)\n", nbfwd);
+#else
+	cprintf ("Fin - %d forward(s)\n", nbfwd);
+#endif
+#else
 #ifdef ENGLISH
 	cprintf ("End - %d forward(s)\r\n", nbfwd);
 #else
 	cprintf ("Fin - %d forward(s)\r\n", nbfwd);
 #endif
+#endif
 }
