@@ -31,7 +31,7 @@
 #include <serv.h>
 #include <modem.h>
 
-#ifdef __LINUX__
+#ifdef __linux__
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -66,7 +66,7 @@ int md_send (int port, char *chaine)
 		{
 		case '~':
 			deb_io ();
-#if defined(__WINDOWS__) || defined(__LINUX__)
+#if defined(__WINDOWS__) || defined(__linux__)
 			WinMSleep (500);
 #endif
 #ifdef __FBBDOS__
@@ -123,7 +123,7 @@ static void md_etoiles (int voie)
 {
 	int port = no_port (voie);
 
-#ifdef __LINUX__
+#ifdef __linux__
 	struct termios tty;
 	defcom *ptrcom = &p_com[(int)p_port[port].ccom];
 
@@ -161,7 +161,7 @@ static void md_etoiles (int voie)
 
 void md_echo (int voie)
 {
-#ifdef __LINUX__
+#ifdef __linux__
 	int port = no_port (voie);
 	struct termios tty;
 	defcom *ptrcom = &p_com[(int)p_port[port].ccom];
@@ -209,7 +209,7 @@ void modem_no_echo (int port)
 
 void init_modem (int port)
 {
-#ifdef __LINUX__
+#ifdef __linux__
 	if (BIOS (port) == P_LINUX)
 	{
 		struct termios tty;
@@ -269,7 +269,7 @@ void init_modem (int port)
 
 void modem_stop (int port)
 {
-#ifdef __LINUX__
+#ifdef __linux__
 	{
 		int comfd = p_com[(int)p_port[port].ccom].comfd;
 
@@ -329,7 +329,7 @@ void modem_start (int port)
 	fen_ptr = open_win (4, 2, 50, 8, INIT, s);
 #endif
 
-#ifdef __LINUX__
+#ifdef __linux__
 	if (BIOS (port) == P_LINUX)
 	{
 		struct termios tty;
@@ -434,7 +434,7 @@ void md_defaut (int voie)
 {
 	int port = no_port (voie);
 
-#ifdef __LINUX__
+#ifdef __linux__
 	if (BIOS (port) == P_LINUX)
 	{
 		struct termios tty;
@@ -478,7 +478,7 @@ int modem_vide (int voie)
 	int nbtot;
 	int port = no_port (voie);
 
-#ifdef __LINUX__
+#ifdef __linux__
 	if (BIOS (port) == P_LINUX)
 	{
 		defcom *ptrcom = &p_com[(int)p_port[port].ccom];
@@ -526,7 +526,7 @@ void md_inbuf (int voie, char *ptr, int nb)
 {
 	in_buf (voie, ptr, nb);
 
-#ifdef __LINUX__
+#ifdef __linux__
 	{
 		defcom *ptrcom = &p_com[(int)p_port[port].ccom];
 		struct termios tty;
@@ -594,6 +594,7 @@ void connect_modem (int voie)
 	svoie[voie]->mess_recu = svoie[voie]->xferok = 1;
 	svoie[voie]->mbl = 1;
 	svoie[voie]->entmes.numero = 0L;
+	svoie[voie]->entmes.theme = 0;
 	svoie[voie]->finf.lang = langue[0]->numlang;
 	svoie[voie]->r_tete = NULL;
 	svoie[voie]->mode = 0;
@@ -654,7 +655,7 @@ void deconnect_modem (int voie)
 
 	/* Attend que le buffer soit vide */
 
-#ifdef __LINUX__
+#ifdef __linux__
 	{
 		int tempo = 100;		/* attend 10s le vidage du modem */
 
@@ -699,7 +700,7 @@ void deconnect_modem (int voie)
 
 	temps = time (NULL) + 2;
 
-#ifdef __LINUX__
+#ifdef __linux__
 	if (BIOS (port) == P_LINUX)
 	{
 		defcom *ptrcom = &p_com[(int)p_port[port].ccom];
