@@ -334,7 +334,7 @@ static void arret_serveur (char *fich_etat, int typ)
 		}
 		texte (T_TRT + 10);
 		maintenance ();			/* reboot serveur */
-#ifdef __LINUX__
+#ifdef __linux__
 		exit (6);
 #endif
 #ifdef __WINDOWS__
@@ -658,7 +658,7 @@ int maj_with_wp (int voie)
 
 	if (EMS_WPG_OK ())
 	{
-		if ((rec = wp_find (svoie[voie]->sta.indicatif.call)) != NULL)
+		if ((rec = wp_find (svoie[voie]->sta.indicatif.call, 1)) != NULL)
 		{
 			ok += wp_val (12, svoie[voie]->finf.prenom, rec->name);
 			ok += wp_val (30, svoie[voie]->finf.ville, rec->first_qth);
@@ -814,9 +814,8 @@ int accept_cnx (void)
 
 		*buffer = '\0';
 
-#ifdef __LINUX__
-		sprintf (s, "%sc_filter %s-%d %d %u %d %d %d",
-				 FILTDIR,
+#ifdef __linux__
+		sprintf (s, "./c_filter %s-%d %d %u %d %d %d",
 				 pvoie->sta.indicatif.call,
 				 pvoie->sta.indicatif.num,
 				 pvoie->niv3, pvoie->finf.flags, new_om,
@@ -935,7 +934,11 @@ static void accueil (void)
 
 	if (accept_cnx ())
 	{
-		if (BBS (pvoie->finf.flags))
+		if (POP (no_port (voiecur)))
+		{
+			/* No text for pop connection */
+		}
+		else if (BBS (pvoie->finf.flags))
 		{
 			texte (T_MES + 0);
 		}
@@ -1131,7 +1134,7 @@ void libere_zones_allouees (int voie)
 	libere_edit (voie);			/* Libere la liste de l'editeur */
 /*  libere_label(voie)        ; Libere les labels de YAPP    */
 	libere_route (voie);		/* Libere les routes rx forward */
-#ifndef __LINUX__
+#ifndef __linux__
 	libere_ymodem (voie, 0);;	/* Libere la liste de fichiers  */
 #endif
 	clear_inbuf (voie);			/* Vide le buffer d'entree      */
